:tocdepth: 1

Citing
------
To cite Trisicell please use the following publication:

Profiles of expressed mutations in single cells reveal patterns of tumor evolution and therapeutic impact of intratumor heterogeneity
Farid Rashidi Mehrabadi, Kerrie L. Marie, Eva Perez-Guijarro, Salem Malikic, Erfan Sadeqi Azer, Howard H. Yang, Can Kizilkale, Charli Gruen, Huaitian Liu, Michael C. Kelly, Christina Marcelus, Sandra Burkett, Aydin Buluc, Funda Ergun, Maxwell P. Lee, Glenn Merlino, Chi-Ping Day, S. Cenk Sahinalp
bioRxiv 2021.03.26.437185; doi: https://doi.org/10.1101/2021.03.26.437185

BibTeX
~~~~~~
.. code-block:: RST
    
    @article{Trisicell,
      doi           = {10.1101/2021.03.26.437185},
      url           = {https://doi.org/10.1101/2021.03.26.437185},
      year          = 2021,
      month         = mar,
      publisher     = {Cold Spring Harbor Laboratory},
      author        = {Farid Rashidi Mehrabadi and Kerrie L. Marie and Eva Perez-Guijarro and Salem Malikic and Erfan Sadeqi Azer and Howard H. Yang and Can Kizilkale and Charli Gruen and Huaitian Liu and Michael C. Kelly and Christina Marcelus and Sandra Burkett and Aydin Buluc and Funda Ergun and Maxwell P. Lee and Glenn Merlino and Chi-Ping Day and S. Cenk Sahinalp},
      title         = {{Profiles of expressed mutations in single cells reveal patterns of tumor evolution and therapeutic impact of intratumor heterogeneity}},
      journal       = {bioRxiv}
    }
